@@ -14,9 +14,9 @@ use constant    DIRECT => 'http://www.amazon.de/gp/product/';
 
 our $DEBUG = $ENV{ISBN_DRIVER_DEBUG};
 
-# ABSTRACT: Search driver for the (DE) Amazon online catalog.
+# ABSTRACT: [DEPRECATED] Search driver for the (DE) Amazon online catalog.
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 
 sub search {
@@ -97,7 +97,7 @@ sub search {
 #                  (.+?)
 #                  \s*:\s*([^:]+)\s*:
 #                  /x);
-#                  #\s*(?:(?:English\sBooks?)|Bcher|B&amp;uuml;cher|B&uuml;cher).*
+#                  #\s*(?:(?:English\sBooks?)|Bücher|B&amp;uuml;cher|B&uuml;cher).*
 #    #$data->{title} =~ s!\(.*?\)$!!;
 
      my @tmp_info = map{ s{\A\s*}{}; $_ }split /:/, $data->{content};
@@ -134,15 +134,18 @@ sub search {
 1; # End of WWW::Scraper::ISBN::AmazonDE_Driver
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-WWW::Scraper::ISBN::AmazonDE_Driver - Search driver for the (DE) Amazon online catalog.
+WWW::Scraper::ISBN::AmazonDE_Driver - [DEPRECATED] Search driver for the (DE) Amazon online catalog.
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -153,6 +156,18 @@ See parent class documentation (L<WWW::Scraper::ISBN::Driver>)
 Searches for book information from the (DE) Amazon online catalog.
 This module is a mere paste and translation of L<WWW::Scraper::ISBN::AmazonFR_Driver>.
 
+=head1 WHY DEPRECATED?
+
+I don't use the module anymore and Amazon seems to change the HTML every now
+and then. That makes it hard to maintain the module.
+
+=head1 ADOPT THE MODULE
+
+If you're interested to adopt the module, then go ahead. I will give (co-)maintainership
+to the L<ADOPTME|https://metacpan.org/author/ADOPTME> user. I can transfer the
+L<Github repository|https://github.com/reneeb/WWW-Scraper-ISBN-AmazonDE_Driver> to you,
+if you send me a mail with your Github-ID.
+
 =head1 FUNCTIONS
 
 =head2 search
@@ -208,15 +223,14 @@ under the terms of Artistic License 2.0.
 
 =head1 AUTHOR
 
-Renee Baecker <module@renee-baecker.de>
+Renee Baecker <reneeb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Renee Baecker.
+This software is Copyright (c) 2015 by Renee Baecker.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
